==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/urls_etendues/lang/urls_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/urls?lang_cible=eo
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'Ĝisdatigi ĉiujn retadresojn (URL)',
	'actualiser_toutes_explication' => 'Vi povas rekonstruigi la retadresojn (URL). Se retadreso ŝanĝas, nova elemento kreiĝos (kaj la jam ekzistantaj retadresoj — per-mana difinita aŭ ne — ne perdiĝos).',

	// B
	'bouton_supprimer_url' => 'Forigi tiun retadreson',

	// E
	'erreur_arbo_2_segments_max' => 'Vi ne povas uzi pli ol du retadresajn partojn por unu objekto',
	'erreur_config_url_forcee' => 'La agordo pri la retadresoj (URL) estas difinita en la dosiero <tt>mes_options.php</tt>.',
	'explication_editer' => 'La detala mastrumado de la retadresoj (URL) ebligas modifi la paĝan retadreson de ĉiu redakta objekto, kaj administri la historion de ĝia evoluo.',

	// I
	'icone_configurer_urls' => 'Agordi la retadresojn',
	'icone_controler_urls' => 'Sencaj retadresoj',
	'info_1_url' => '1 retadreso',
	'info_id_parent' => '#patra (patra identigilo)',
	'info_nb_urls' => '@nb@ retadresojn',
	'info_objet' => 'Objekto',

	// L
	'label_tri_date' => 'Dato',
	'label_tri_id' => 'Identigilo',
	'label_tri_url' => 'Retadreso (URL)',
	'label_url' => 'Nova retadreso (URL)',
	'label_url_minuscules_0' => 'Konservi la usklecon de la titolo',
	'label_url_minuscules_1' => 'Minuskligi la retadresojn',
	'label_url_permanente' => 'Ŝlosi tiun retadreson (ne ĝisdatigo post la redakto de la objekto)',
	'label_url_sep_id' => 'Signo uzota por dislimi la numeron aldonitan okaze de duoblo',
	'label_urls_activer_controle_oui' => 'Aktivigi detalan agordon pri retadresoj',
	'label_urls_nb_max_car' => 'Maksimuma nombro de signoj',
	'label_urls_nb_min_car' => 'Minimuma nombro de signoj',
	'liberer_url' => 'Liberigi',
	'liste_des_urls' => 'Ĉiuj retadresoj',

	// T
	'texte_type_urls' => 'Vi povas elekti ĉi-tie, kiel la adreso (URL) de la paĝoj konstruiĝas.',
	'texte_type_urls_attention' => 'Atentu. Tiu agordo funkcios, nur se la dosiero @htaccess@ estas instalita en la radiko de la retejo.',
	'texte_urls_nb_max_car' => 'Se la titolo estas pli longa, ĝi estos fortranĉita.',
	'texte_urls_nb_min_car' => 'Se la titolo estas pli mallonga, ĝia numera identigilo uziĝos.',
	'titre_gestion_des_urls' => 'Mastrumado de la retadresoj (URL)',
	'titre_type_arbo' => 'Arbaj retadresojn',
	'titre_type_html' => 'HTML-objektaj retadresoj',
	'titre_type_libres' => 'Laŭvolaj retadresoj',
	'titre_type_page' => 'Paĝaj retadresoj',
	'titre_type_propres' => 'Puraj retadresoj',
	'titre_type_propres2' => 'Puraj retadresoj + <tt>.html</tt>',
	'titre_type_propres_qs' => 'Puraj retadresoj per informpeta ĉeno („query string“)',
	'titre_type_simple' => 'Simplaj retadresoj',
	'titre_type_standard' => 'Heredaj retadresoj',
	'titre_type_urls' => 'Tipo de retadreso',
	'tout_voir' => 'Vidu ĉiujn retadresojn',

	// U
	'url_ajout_impossible' => 'Eraro okazis. Ne eblis savi tiun retadreson',
	'url_ajoutee' => 'Retadreso aldonita',

	// V
	'verifier_url_nettoyee' => 'La retadreso korektiĝis, vi povas kontroli ĝin antaŭ ol registri ĝin.',
	'verrouiller_url' => 'Ŝlosi'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/urls_etendues/lang/urls_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/urls?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// A
	'actualiser_toutes' => 'Ĝisdatigi ĉiujn retadresojn (URL)',
	'actualiser_toutes_explication' => 'Vi povas rekonstruigi la retadresojn (URL). Se retadreso ŝanĝas, nova elemento kreiĝos (kaj la jam ekzistantaj retadresoj — per-mana difinita aŭ ne — ne perdiĝos).',

	// B
	'bouton_supprimer_url' => 'Forigi tiun retadreson',

	// E
	'erreur_arbo_2_segments_max' => 'Vi ne povas uzi pli ol du retadresajn partojn por unu objekto',
	'erreur_config_url_forcee' => 'La agordo pri la retadresoj (URL) estas difinita en la dosiero <tt>mes_options.php</tt>.',
	'explication_editer' => 'La detala mastrumado de la retadresoj (URL) ebligas modifi la paĝan retadreson de ĉiu redakta objekto, kaj administri la historion de ĝia evoluo.',

	// I
	'icone_configurer_urls' => 'Agordi la retadresojn',
	'icone_controler_urls' => 'Sencaj retadresoj',
	'info_1_url' => '1 retadreso',
	'info_id_parent' => '#patra (patra identigilo)',
	'info_nb_urls' => '@nb@ retadresojn',
	'info_objet' => 'Objekto',

	// L
	'label_tri_date' => 'Dato',
	'label_tri_id' => 'Identigilo',
	'label_tri_url' => 'Retadreso (URL)',
	'label_url' => 'Nova retadreso (URL)',
	'label_url_minuscules_0' => 'Konservi la usklecon de la titolo',
	'label_url_minuscules_1' => 'Minuskligi la retadresojn',
	'label_url_permanente' => 'Ŝlosi tiun retadreson (ne ĝisdatigo post la redakto de la objekto)',
	'label_url_sep_id' => 'Signo uzota por dislimi la numeron aldonitan okaze de duoblo',
	'label_urls_activer_controle_oui' => 'Aktivigi detalan agordon pri retadresoj',
	'label_urls_nb_max_car' => 'Maksimuma nombro de signoj',
	'label_urls_nb_min_car' => 'Minimuma nombro de signoj',
	'liberer_url' => 'Liberigi',
	'liste_des_urls' => 'Ĉiuj retadresoj',

	// T
	'texte_type_urls' => 'Vi povas elekti ĉi-tie, kiel la adreso (URL) de la paĝoj konstruiĝas.',
	'texte_type_urls_attention' => 'Atentu. Tiu agordo funkcios, nur se la dosiero @htaccess@ estas instalita en la radiko de la retejo.',
	'texte_urls_nb_max_car' => 'Se la titolo estas pli longa, ĝi estos fortranĉita.',
	'texte_urls_nb_min_car' => 'Se la titolo estas pli mallonga, ĝia numera identigilo uziĝos.',
	'titre_gestion_des_urls' => 'Mastrumado de la retadresoj (URL)',
	'titre_type_arbo' => 'Arbaj retadresojn',
	'titre_type_html' => 'HTML-objektaj retadresoj',
	'titre_type_libres' => 'Laŭvolaj retadresoj',
	'titre_type_page' => 'Paĝaj retadresoj',
	'titre_type_propres' => 'Puraj retadresoj',
	'titre_type_propres2' => 'Puraj retadresoj + <tt>.html</tt>',
	'titre_type_propres_qs' => 'Puraj retadresoj per informpeta ĉeno („query string“)',
	'titre_type_simple' => 'Simplaj retadresoj',
	'titre_type_standard' => 'Heredaj retadresoj',
	'titre_type_urls' => 'Tipo de retadreso',
	'tout_voir' => 'Vidu ĉiujn retadresojn',

	// U
	'url_ajout_impossible' => 'Eraro okazis. Ne eblis savi tiun retadreson',
	'url_ajoutee' => 'Retadreso aldonita',

	// V
	'verifier_url_nettoyee' => 'La retadreso korektiĝis, vi povas kontroli ĝin antaŭ ol registri ĝin.',
	'verrouiller_url' => 'Ŝlosi',
];
